@@ -14,6 +14,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+# For Python 2.5
+from __future__ import with_statement
+
 """Processes crontab files and try to catch common errors.
 
 Parse crontab files and check each type of line for potential syntax errors.
@@ -285,16 +288,17 @@ def InitCronFSM():
   fsm.AddTransition(',', 'range_step', ActionRangeStepComma, 'next')
 
   # Case: <text>
-  fsm.AddTransition(string.letters, 'start', ActionTime, 'text')
-  fsm.AddTransition(string.letters, 'next', ActionTime, 'text')
-  fsm.AddTransition(string.letters, 'text', ActionTime, 'text')
+  fsm.AddTransition(string.ascii_letters, 'start', ActionTime, 'text')
+  fsm.AddTransition(string.ascii_letters, 'next', ActionTime, 'text')
+  fsm.AddTransition(string.ascii_letters, 'text', ActionTime, 'text')
   fsm.AddEndState('text', ActionTextComma)
   fsm.AddTransition(',', 'text', ActionTextComma, 'next')
   # Case: <text>-<text>
   fsm.AddTransition('-', 'text', ActionDash, 'start_text_range')
-  fsm.AddTransition(string.letters, 'start_text_range', ActionTime,
+  fsm.AddTransition(string.ascii_letters, 'start_text_range', ActionTime,
+                    'text_range')
+  fsm.AddTransition(string.ascii_letters, 'text_range', ActionTime,
                     'text_range')
-  fsm.AddTransition(string.letters, 'text_range', ActionTime, 'text_range')
   fsm.AddEndState('text_range', ActionTextRangeComma)
   fsm.AddTransition(',', 'text_range', ActionTextRangeComma, 'next')
   # Case: <text>-<text>/<text>
@@ -891,7 +895,7 @@ class LogCounter(object):
     Args:
       message: The message to print as a warning.
     """
-    print 'W:', message
+    print('W:', message)
     self._warn_count += 1
 
   def LineWarn(self, msg_kind, line_warn):
@@ -915,7 +919,7 @@ class LogCounter(object):
     Args:
       message: The message to print as a error.
     """
-    print 'E:', message
+    print('E:', message)
     self._error_count += 1
 
   def LineError(self, msg_kind, line_error):
@@ -946,13 +950,13 @@ class LogCounter(object):
       line_error_fmt = 'e: %s  %%s' % spacer
       line_warn_fmt = 'w: %s  %%s' % spacer
       if self._line_errors:
-        print 'E: %d: %s' % (line_no, line)
+        print('E: %d: %s' % (line_no, line))
       else:
-        print 'W: %d: %s' % (line_no, line)
+        print('W: %d: %s' % (line_no, line))
       for line_error in self._line_errors:
-        print line_error_fmt % line_error
+        print(line_error_fmt % line_error)
       for line_warn in self._line_warns:
-        print line_warn_fmt % line_warn
+        print(line_warn_fmt % line_warn)
       self._line_errors = []
       self._line_warns = []
 
@@ -970,11 +974,11 @@ class LogCounter(object):
     if self._error_count > 0:
       print('E: There were %d errors and %d warnings.'
             % (self._error_count, self._warn_count))
-      print more_info
+      print(more_info)
       return 2
     elif self._warn_count > 0:
-      print 'W: There were %d warnings.' % self._warn_count
-      print more_info
+      print('W: There were %d warnings.' % self._warn_count)
+      print(more_info)
       return 1
     else:
       return 0
@@ -1023,14 +1027,15 @@ def CheckCrontab(crontab_file, log):
 
   line_no = 0
   cron_line_factory = CronLineFactory()
-  for line in open(crontab_file, 'r'):
-    line = line.strip()
-    line_no += 1
+  with open(crontab_file, 'r') as crontab_f:
+    for line in crontab_f:
+      line = line.strip()
+      line_no += 1
 
-    cron_line = cron_line_factory.ParseLine(line)
-    cron_line.ValidateAndLog(log)
+      cron_line = cron_line_factory.ParseLine(line)
+      cron_line.ValidateAndLog(log)
 
-    log.Emit(line_no, line)
+      log.Emit(line_no, line)
 
   # Summarize the log messages if there were any.
   return log.Summary()
@@ -1040,7 +1045,7 @@ def main():
   log = LogCounter()
   if len(sys.argv) != 2:
     log.Error('Must provide a crontab file to check.')
-  print 'Checking correctness of %s' % sys.argv[1]
+  print('Checking correctness of %s' % sys.argv[1])
   return CheckCrontab(sys.argv[1], log)
 
 
